@@ -126,7 +126,7 @@ repository = %(repository_path)s
         assert master.getProtocolRevision() == 1
         test_result = safeRpcCall(master.createTestResult,
           config['test_suite_name'], revision, [],
-          False)
+          False, config['computer_id'])
       print "testnode, test_result : %r" % (test_result,)
       if test_result:
         test_result_path, test_revision = test_result
